
from setuptools import setup, find_packages

setup(
    name="wsxtext009",     # 👈 nombre único en PyPI
    version="0.5.0",
    author="Tu Nombre",
    author_email="fededimant@hotmail.com",
    description="Paquete de ejemplo subido desde Google Colab",
    long_description="Ejemplo minimalista",
    long_description_content_type="text/markdown",
    url="https://github.com/fededimant/wsxtext009",
    packages=find_packages(),

)
